# %W% %G%
# Imakefile for mvfs_param.c
#
#
# ------------------------------------------------------------------
# | Copyright Unpublished, Atria Software, Inc.  All Rights        |
# | Reserved.  This software contains proprietary and confidential |
# | information of Atria and its suppliers.  Use, disclosure or    |
# | reproduction is prohibited without the prior express written   |
# | consent of Atria.                                              |
# ------------------------------------------------------------------
# 
# Makefile for mvfs parameters
# mvfs_param.c needs to be compiled on the target system
# to ensure it picks up target-specific parameter and
# offset values, and so that the user can configure it.
#

ROOT=
MAKE= make

# Common to MVFS installation on any version
MVFSLIB= libusrdrv.a
RM_AR_FILES= mvfs.o mvfs_param.o

# Macros to handle differences between HP-UX releases
CC11=	/usr/ccs/bin/cc
AR11=	/usr/ccs/bin/ar
LIB11=     /usr/conf/lib/$(MVFSLIB)
AR_FILES_11.22_32= "B.11.22_32/mvfs.o mvfs_param.o"
AR_FILES_11.22_64= "B.11.22_64/mvfs.o mvfs_param.o"

# Kernel options particular to each architecture
OFLAGS=+ESdbgasm #-g
HP-IA64.MACHOPTS=-U__hp9000s700 -D__NO_PA_HDRS
HP-IA64.CCOPTS= -Wp,-H300000 $(OFLAGS) +kernel #-Ae

## not supported?
##HP-11.COPTS= "${IDENT} ${OPTIONS} -DKERNEL -D_KERNEL \
##	-D_KERNEL_BUILD -D_UNSUPPORTED -DATRIA_HPUX10 -DATRIA_HPUX11 +DO10.20"
HP-11.COPTS.LP64= "${IDENT} ${OPTIONS} -DKERNEL -D_KERNEL \
	-D_KERNEL_BUILD -D_UNSUPPORTED -DATRIA_HPUX10 -DATRIA_HPUX11 +DD64"

# no default, caller must specifiy action 
unspecified:
	@echo "Error: No action specified.  Must specify one of: install, regen, deinstall"

# three operations are supported by this makefile:
#   a) installing the MVFS (install)
#   b) rebuilding the MVFS after tuning mvfs_param.c (regen)
#   c) deinstalling the MVFS (deinstall)
# 

regen:
	@$(MAKE) -f mvfs_param.mk install

install:
	@case `uname -r` in \
    B.11.22) \
      if [ `getconf KERNEL_BITS` -eq 32 ]; then \
       $(MAKE) -f mvfs_param.mk CC=$(CC11) AR=$(AR11) OPTS=$(HP-11.COPTS) \
          DEST=$(LIB11) AR_FILES=$(AR_FILES_11.22_32) build.mvfs ; \
      else   \
       $(MAKE) -f mvfs_param.mk CC=$(CC11) AR=$(AR11) OPTS=$(HP-11.COPTS.LP64) \
          DEST=$(LIB11) AR_FILES=$(AR_FILES_11.22_64) build.mvfs ; \
      fi \
    ;;  \
    esac

build.mvfs: mvfs_param.o
	$(AR) r $(DEST) $(AR_FILES)

mvfs_param.o: mvfs_param.c
	$(CC) -c -w -I.. -I../h $(OPTS) $(HP-IA64.MACHOPTS) $(HP-IA64.CCOPTS) mvfs_param.c


# deinstall MVFS: remove objects from libusrdrv.a, and if it is now empty,
#                 remove the archive itself
#
deinstall:
	@case `uname -r` in \
    *.11.*) \
        $(MAKE) -f mvfs_param.mk AR=$(AR11) DEST=$(LIB11) rm.mvfs  \
    ;; \
    *.10.*) \
        $(MAKE) -f mvfs_param.mk AR=$(AR11) DEST=$(LIB11) rm.mvfs  \
    ;; \
    esac

rm.mvfs:   
	-rm mvfs_param.o
	-$(AR) d $(DEST) $(RM_AR_FILES)
	@if [ "X`$(AR) tv $(DEST)`" = "X" ] ; then \
		rm $(DEST); fi

